@@ -1,12 +1,33 @@
-/* Yes, this is evil code. But many people seem to like hazardous things, so
- * it exists. Most of this was written by Kulyk Nazar.
+/* Clearlooks - a cairo based GTK+ engine
+ * Copyright (C) 2006 Kulyk Nazar <schamane@myeburg.net>
+ * Copyright (C) 2006-2007 Benjamin Berg <benjamin@sipsolutions.net>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * Project contact: <gnome-themes-list@gnome.org>
+ *
+ *
+ * This code is responsible for the clearlooks animation support. The code
+ * works by forcing a redraw on the animated widget.
  *
- * heavily modified by Benjamin Berg <benjamin@sipsolutions.net>.
  */
+ 
 
 #include "animation.h"
 
-#ifdef HAVE_ANIMATION
+#ifdef HAVE_WORKING_ANIMATION
 #include <glib/gtimer.h>
 
 struct _AnimationInfo {
@@ -309,9 +330,12 @@ clearlooks_animation_cleanup ()
 	
 	stop_timer ();
 }
-#else /* !HAVE_ANIMATION */
+#else /* !HAVE_WORKING_ANIMATION */
+/* Warn here so the message is only displayed once. */
+#warning Disabling animation support as it currently needs deprecated symbols and GTK_DISABLE_DEPRECATED is enabled.
+
 static void clearlooks_animation_dummy_function_so_wall_shuts_up_when_animations_is_disabled()
 {
 	clearlooks_animation_dummy_function_so_wall_shuts_up_when_animations_is_disabled();
 }
-#endif /* HAVE_ANIMATION */
+#endif /* HAVE_WORKING_ANIMATION */
